@@ -1,4 +1,4 @@
 # __init__.py
-import vms
+__all__ = ["vms", "icon"]
 # Version of the realpython-reader package
-__version__ = "0.1.1"
+__version__ = "0.1.2"
